@@ -1,5 +1,5 @@
 import math
-from objects import Enemy, Laser
+from bluebeam.objects import Enemy, Laser
 import time
 import pygame, os
 from pygame import Vector2 as vec2
